@@ -24,13 +24,14 @@ Created on 30 Mar 2020
 @author: mboscolo
 '''
 #
-
+from flask_admin.form import DatePickerWidget, DateTimePickerWidget
 from flask_wtf import FlaskForm
 import wtforms as fields
+import wtforms.validators as validator
 from .convetion import WTF_TRYTON_FIELD_MAPPING
 from .convetion import WTF_TRYTON_FIELD_ATTRIBUTES_MAPPING
 from .convetion import WTF_TRYTON_FIELD_ATTRIBUTES_SPECIFIC
-  
+
 
 class TFlaskForm(FlaskForm):
     trytonObject = None
@@ -43,19 +44,22 @@ class TFlaskForm(FlaskForm):
     def __init__(self, *arg, **kargs):
         self._trytonId = None
         self.GetWtfFromTryton()
-        self._unbound_fields.append((self.submitLable, fields.SubmitField(self.submitLable)))
+        self._unbound_fields.append(('submit', fields.SubmitField(self.submitLable)))
         super(TFlaskForm, self).__init__(*arg, **kargs)
-        pass
 
     def GetWtfFromTryton(self):
         """
         Get a brand new FlaskForm created from tryton module
         """
-        trytonFields = self.trytonObject._fields.keys()
-        values = self.trytonObject.default_get(trytonFields)
-        for tryton_field_name in trytonFields :
+        allTrytonFields = self.trytonObject._fields.keys()
+        values = self.trytonObject.default_get(self.tryton_fields)
+        if not self.tryton_fields:
+            tryton_fields = allTrytonFields
+        else:
+            tryton_fields = self.tryton_fields
+        for tryton_field_name in tryton_fields :
             
-            if self.tryton_fields and tryton_field_name not in self.tryton_fields:
+            if tryton_fields and tryton_field_name not in allTrytonFields:
                 continue  
             field = self.trytonObject._fields.get(tryton_field_name)
             wtField = WTF_TRYTON_FIELD_MAPPING.get(field._type)
@@ -73,12 +77,15 @@ class TFlaskForm(FlaskForm):
                 if 'label' not in wtFielAttibutes:
                     wtFielAttibutes['label'] = tryton_field_name
                 wtFielAttibutes['default'] = values.get(tryton_field_name)
-#                 if field._type in ['time','date','datetime']:
-#                     format = self.tryton_fields.get(tryton_field_name, {}).get('format')
-#                     if format and values.get(tryton_field_name):
-#                         wtFielAttibutes['default'] = values.get(tryton_field_name).strftime(format)
-
-                wtFielAttibutes.update(self.tryton_fields.get(tryton_field_name, {}))
+                wtFielAttibutes.update(tryton_fields.get(tryton_field_name, {}))
+                if field._type == 'datetime':
+                    wtFielAttibutes['widget'] = DateTimePickerWidget()
+                if field._type == 'date':
+                    wtFielAttibutes['widget'] = DatePickerWidget()
+                if field.required:
+                    validators = wtFielAttibutes.get('validators',[])
+                    validators.append(validator.DataRequired())
+                    wtFielAttibutes['validators']=validators
                 self._unbound_fields.append((tryton_field_name, wtField(**wtFielAttibutes)))
             else:
                 raise NotImplementedError("Widget for filed %r not implemented" % tryton_field_name)
